@@ -15,12 +15,16 @@ class JSONSource(Source):
     Example configuration::
 
          ...
+
          "args": {
-             'hello': {
-                 'frametype': 'dict',
-                 'filename': '%(data_root)s/shared/hello.json',
-                 'params': {}
+             "source": {
+                 'hello': {
+                     'frametype': 'dict',
+                     'filename': '%(data_root)s/shared/hello.json',
+                     'params': {}
+                 }
              }
+         }
     """
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -29,10 +33,12 @@ class JSONSource(Source):
         self.testdata = {
             'conf': {
                 'args': {
-                    'hello': {
-                        'filename': '%(data_root)s/shared/hello.json',
-                        'frametype': 'dict',
-                        'params': {
+                    'source': {
+                        'hello': {
+                            'filename': '%(data_root)s/shared/hello.json',
+                            'frametype': 'dict',
+                            'params': {
+                            }
                         }
                     }
                 }
@@ -48,12 +54,21 @@ class JSONSource(Source):
         specification.
         """
 
+        # Backward compatabilty
+        if 'source' not in args:
+            args = {
+                'source': args
+            }
+
         args = super().preload_clean_args(args)
 
         # Sanity check...
         assert isinstance(args, dict)
+        assert 'source' in args
+        assert isinstance(args['source'], dict)
 
-        for name, detail  in args.items():
+        source = args['source']
+        for name, detail  in source.items():
 
             if (("frametype" not in detail) or
                 (detail['frametype'] != 'dict')):
@@ -91,7 +106,11 @@ class JSONSource(Source):
         Double check the arguments
         """
         assert isinstance(self.args, dict)
-        for name, detail  in self.args.items():
+        assert 'source' in self.args
+        assert isinstance(self.args['source'], dict)
+
+        source = self.args['source']
+        for name, detail  in source.items():
             assert (('frametype' in detail) and (detail['frametype'] == 'dict'))
             assert 'filename' in detail
             assert 'params' in detail
@@ -105,7 +124,8 @@ class JSONSource(Source):
                          'transform': self.name
                      }))
 
-        for name, detail  in self.args.items():
+        source = self.args['source']
+        for name, detail  in source.items():
 
             filename = detail['filename']
             data = json.load(open(filename))
@@ -155,7 +175,8 @@ class JSONSource(Source):
         Check to make sure that the execution completed correctly
         """
 
-        for name, detail  in self.args.items():
+        source = self.args['source']
+        for name, detail  in source.items():
             if not state.reached_stage(name, self.name):
                 raise Exception("Could not find new frame created for {}".format(name))
 
