@@ -358,7 +358,6 @@ class RunBase(object):
                 # Now collect information from lineage metadata
                 if _type == 'lineage':
 
-                    #print(json.dumps(p, indent=4))
                     # Extract lineage information
                     dependencies = p.get('dependencies', [])
                     for d in dependencies:
@@ -374,9 +373,10 @@ class RunBase(object):
                         # (c) a dict: name => list
                         # (d) a dict: name => dict
                         objects = d.get('objects',{})
-                        #print("Objects", objects)
                         if isinstance(objects, list):
                             for name in objects:
+                                if not isinstance(name, str):
+                                    continue
                                 if nature == 'input':
                                     if name not in inputs:
                                         inputs[name] = name
